@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pandoc
 version: 1.17.0.3
-id: pandoc-1.17.0.3-a12df7a7745e5ea4de39fe36e7ff7b76
-key: pando_Ic8iW0y3niIE97JSXnLXg8
+id: pandoc-1.17.0.3-257df634e15a54e32a712d876ce77ba5
+key: pando_CqT84VqTutCBL5A3uDfVvt
 license: GPL
 copyright: (c) 2006-2016 John MacFarlane
 maintainer: John MacFarlane <jgm@berkeley.edu>
@@ -85,7 +85,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-1.17.0.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-1.17.0.3
 data-dir: /usr/share/pandoc
-hs-libraries: HSpandoc-1.17.0.3-Ic8iW0y3niIE97JSXnLXg8
+hs-libraries: HSpandoc-1.17.0.3-CqT84VqTutCBL5A3uDfVvt
 depends:
     HTTP-4000.3.3-e80abaf8bcce3e49baa17e1fe8d694c7
     JuicyPixels-3.2.7-7a5ea2c8822f98f6d9837c143b0f3055
@@ -125,14 +125,14 @@ depends:
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
     tagsoup-0.13.9-61f7129b459feb0b7d9b7f0c4b3300d3
     temporary-1.2.0.4-82bc44ff7d47fd2873d477b044a2a6ac
-    texmath-0.8.5.1-12fde9597135cf71aeccebd23ab95779
+    texmath-0.8.6.1-5f9e05ceca1cc643ef8bc76de94907d1
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
     xml-1.3.14-6291d85df68e094bfca87f33fea8b24c
     yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
-    zip-archive-0.3-2c98cfc50f306ecd4e01363be7a8d981
+    zip-archive-0.3.0.1-2bfc79c766a6020efc6123272df9282f
     zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
 haddock-interfaces: /usr/share/doc/pandoc/html/pandoc.haddock
 haddock-html: /usr/share/doc/pandoc/html
